%% 
%% This is file `formtechforum.cls' constructed by Ton van den Boogaard,
%% based on many examples from different conferences and authors.
%% The file provides formatting in a 2-column style.
%% 
%% This file requires a different abstract command than the standard
%% abstract environment.
%%
%% \title{...}
%% \author{...}
%% \abstract{...}
%% \keywords{...}
%% \begin{document}
%% \maketitle   <------  maketitle after beginning document.
%% \thispagestyle{fancy}
%%
%% The regular article class commands still exist and may be used,
%% with the exception of the abstract environment. Use the redefined
%% \abstract command instead. The 11pt, 12pt and onecolumn options
%% are disabled.
%%
%% IMPORTANT:
%% The textsize and margins are defined in this file.
%% You need a large enough papersize to print it on, e.g. A4.
%% To get the prescribed Forming Technology Forum format also use the
%% accompanying example.tex file.
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{formtechforum}[Forming Technology Forum paper class]

\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{onecolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ProcessOptions\relax

\LoadClass[10pt,a4paper,twocolumn,twoside]{article}

\RequirePackage{fancyhdr}
\fancyhead[LE,LO]{\sffamily Forming Technology Forum 2022}
\fancyhead[RE,RO]{\sffamily September 21 \& 22, 2022, Enschede, The Netherlands}
\fancyfoot{}
\renewcommand{\headrulewidth}{0pt}
\pagestyle{fancy}

%% Title and abstract style.

\renewcommand{\@maketitle}{%
  \newpage
  \null
    \begin{center}%
      \vspace{12pt}\par%
      {\Large\bfseries\MakeUppercase \@title \par}%
      \vspace{24pt}%
      {\large\bfseries
          \@author
        \par }%
    \end{center}
    \vspace{12pt}\par
  {\large\bfseries ABSTRACT}
  {\\[12pt] \@abstract}
  \vspace{1em}
  \par
  {\large\bfseries KEYWORDS:}
  {\@keywords}
  \vspace{1em}
  \par
  \vspace{1.5em}} % end of \@maketitle

\gdef\@abstract{}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

\gdef\@keywords{}
\newcommand{\keywords}[1]{\gdef\@keywords{#1}}

\renewcommand{\thesubsection}   {\textup{\thesection.\arabic{subsection}}}
\renewcommand{\thesubsubsection}{\textup{\thesubsection .\arabic{subsubsection}}}

\renewcommand{\section}{\@startsection{section}{1}{0mm}%
                                     {-12pt}%
                                     {6pt}%
                                     {\normalfont\large\bfseries\MakeUppercase}}%
\renewcommand{\subsection}{\@startsection{subsection}{2}{0mm}%
                                     {-10pt}%
                                     {5pt}%
                                     {\normalfont\normalsize\bfseries\MakeUppercase}}%
\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{0mm}%
                                     {-10pt}%
                                     {0.1pt}%
                                     {\normalfont\normalsize\bfseries}}%

\setlength{\voffset}{-1in}
\setlength{\hoffset}{-1in}
\setlength{\topmargin}{15mm}
\setlength{\headheight}{5mm}
\setlength{\headsep}{5mm}
\setlength{\oddsidemargin}{31mm}
\setlength{\evensidemargin}{25mm}
\setlength{\textheight}{247mm}
\setlength{\textwidth}{154mm}
\setlength{\columnsep}{8mm}
\setlength{\textfloatsep}{13pt}
\setlength{\parindent}{0pt}
\setlength{\intextsep}{10pt}
\setlength{\textfloatsep}{10pt}

